Documentation
¶
Index ¶
Constants ¶
const DepinjectModuleName = "tx"
DepinjectModuleName is the module name used for depinject.
Variables ¶
This section is empty.
Functions ¶
func NewBankKeeperCoinMetadataQueryFn ¶
func NewBankKeeperCoinMetadataQueryFn(bk BankKeeper) textual.CoinMetadataQueryFn
NewBankKeeperCoinMetadataQueryFn creates a new Textual struct using the given BankKeeper to retrieve coin metadata.
func NewGRPCCoinMetadataQueryFn ¶
func NewGRPCCoinMetadataQueryFn(grpcConn grpc.ClientConnInterface) textual.CoinMetadataQueryFn
NewGRPCCoinMetadataQueryFn returns a new Textual instance where the metadata queries are done via gRPC using the provided GRPC client connection. In the SDK, you can pass a client.Context as the GRPC connection.
Example:
clientCtx := client.GetClientContextFromCmd(cmd) txt := tx.NewTextualWithGRPCConn(clientCtx)
This should be used in the client (root.go) of an application.
func ProvideProtoRegistry ¶
func ProvideProtoRegistry() txsigning.ProtoFileResolver
Types ¶
type BankKeeper ¶
type BankKeeper interface {
DenomMetadataV2(c context.Context, req *bankv1beta1.QueryDenomMetadataRequest) (*bankv1beta1.QueryDenomMetadataResponse, error)
}
BankKeeper defines the contract needed for tx-related APIs
type ModuleInputs ¶
type ModuleInputs struct {
depinject.In
Config *txconfigv1.Config
AddressCodec address.Codec
ValidatorAddressCodec address.ValidatorAddressCodec
Codec codec.Codec
ProtoFileResolver txsigning.ProtoFileResolver
CustomSignModeHandlers func() []txsigning.SignModeHandler `optional:"true"`
CustomGetSigners []txsigning.CustomGetSigner `optional:"true"`
}
type ModuleOutputs ¶
type ModuleOutputs struct {
depinject.Out
BaseAppOption runtime.BaseAppOption // This is only useful for chains using baseapp.
TxConfig client.TxConfig
TxConfigOptions tx.ConfigOptions
TxSigningHandlerMap *txsigning.HandlerMap
}
func ProvideModule ¶
func ProvideModule(in ModuleInputs) ModuleOutputs
Click to show internal directories.
Click to hide internal directories.